# shimpan

Create exe shims easily. Never modify your PATH again!

Can create 2 types of shims, ['scoop'](https://github.com/ScoopInstaller/Shim) shim is built on .NET and ['alt'](https://github.com/71/scoop-better-shimexe) is C.

You can use it as a lightweight way to publish your app without using Scoop, Chocolatey or Winget.



